import type { AccessEventFlags, AccessWitnessInterface } from '@ethereumjs/common';
import type { Address, PrefixedHexString, VerkleCrypto } from '@ethereumjs/util';
type StemAccessEvent = {
    write?: boolean;
};
type ChunkAccessEvent = StemAccessEvent & {
    fill?: boolean;
};
type StemMeta = {
    address: Address;
    treeIndex: number | bigint;
};
type RawAccessedState = {
    address: Address;
    treeIndex: number | bigint;
    chunkIndex: number;
    chunkKey: PrefixedHexString;
};
export declare enum AccessedStateType {
    Version = "version",
    Balance = "balance",
    Nonce = "nonce",
    CodeHash = "codeHash",
    CodeSize = "codeSize",
    Code = "code",
    Storage = "storage"
}
type AccessedState = {
    type: Exclude<AccessedStateType, AccessedStateType.Code | AccessedStateType.Storage>;
} | {
    type: AccessedStateType.Code;
    codeOffset: number;
} | {
    type: AccessedStateType.Storage;
    slot: bigint;
};
export type AccessedStateWithAddress = AccessedState & {
    address: Address;
    chunkKey: PrefixedHexString;
};
export declare class AccessWitness implements AccessWitnessInterface {
    stems: Map<PrefixedHexString, StemAccessEvent & StemMeta>;
    chunks: Map<PrefixedHexString, ChunkAccessEvent>;
    verkleCrypto: VerkleCrypto;
    constructor(opts?: {
        verkleCrypto?: VerkleCrypto;
        stems?: Map<PrefixedHexString, StemAccessEvent & StemMeta>;
        chunks?: Map<PrefixedHexString, ChunkAccessEvent>;
    });
    touchAndChargeProofOfAbsence(address: Address): bigint;
    touchAndChargeMessageCall(address: Address): bigint;
    touchAndChargeValueTransfer(caller: Address, target: Address): bigint;
    touchAndChargeContractCreateInit(address: Address): bigint;
    touchAndChargeContractCreateCompleted(address: Address): bigint;
    touchTxOriginAndComputeGas(origin: Address): bigint;
    touchTxTargetAndComputeGas(target: Address, { sendsValue }?: {
        sendsValue?: boolean;
    }): bigint;
    touchCodeChunksRangeOnReadAndChargeGas(contact: Address, startPc: number, endPc: number): bigint;
    touchCodeChunksRangeOnWriteAndChargeGas(contact: Address, startPc: number, endPc: number): bigint;
    touchAddressOnWriteAndComputeGas(address: Address, treeIndex: number | bigint, subIndex: number | Uint8Array): bigint;
    touchAddressOnReadAndComputeGas(address: Address, treeIndex: number | bigint, subIndex: number | Uint8Array): bigint;
    touchAddressAndChargeGas(address: Address, treeIndex: number | bigint, subIndex: number | Uint8Array, { isWrite }: {
        isWrite?: boolean;
    }): bigint;
    touchAddress(address: Address, treeIndex: number | bigint, subIndex: number | Uint8Array, { isWrite }?: {
        isWrite?: boolean;
    }): AccessEventFlags;
    /**Create a shallow copy, could clone some caches in future for optimizations */
    shallowCopy(): AccessWitness;
    merge(accessWitness: AccessWitness): void;
    rawAccesses(): Generator<RawAccessedState>;
    accesses(): Generator<AccessedStateWithAddress>;
}
export declare function decodeAccessedState(treeIndex: number | bigint, chunkIndex: number): AccessedState;
export declare function decodeValue(type: AccessedStateType, value: PrefixedHexString | null): string;
export {};
//# sourceMappingURL=accessWitness.d.ts.map